==> gravitino-1.0.0-src.tar.gz: gravitino-1.0.0-src/common/src/test/java/org/apache/gravitino/dto/rel/TestTableDTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.gravitino.dto.rel;

import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
import static org.junit.jupiter.api.Assertions.assertThrows;

import java.time.Instant;
import org.apache.gravitino.dto.AuditDTO;
import org.apache.gravitino.rel.types.Types;
import org.junit.jupiter.api.Test;

public class TestTableDTO {
  @Test
  public void testBuildWithoutColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    TableDTO.Builder<?> builder = TableDTO.builder().withName("t1").withAudit(audit);
    assertThrows(IllegalArgumentException.class, builder::build);
  }

  @Test
  public void testBuildWithEmptyColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    TableDTO.Builder<?> builder =
        TableDTO.builder().withName("t1").withAudit(audit).withColumns(new ColumnDTO[0]);
    assertThrows(IllegalArgumentException.class, builder::build);
  }

  @Test
  public void testBuildWithColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    ColumnDTO column =
        ColumnDTO.builder().withName("c1").withDataType(Types.IntegerType.get()).build();
    TableDTO.Builder<?> builder =
        TableDTO.builder().withName("t1").withAudit(audit).withColumns(new ColumnDTO[] {column});
    assertDoesNotThrow(builder::build);
  }
}

==> gravitino-1.1.0-src.tar.gz: gravitino-1.1.0-src/common/src/test/java/org/apache/gravitino/dto/rel/TestTableDTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.gravitino.dto.rel;

import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;

import java.time.Instant;
import org.apache.gravitino.dto.AuditDTO;
import org.apache.gravitino.rel.types.Types;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class TestTableDTO {
  @Test
  public void testBuildWithoutColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    TableDTO.Builder<?> builder = TableDTO.builder().withName("t1").withAudit(audit);
    Assertions.assertDoesNotThrow(
        () -> {
          builder.build();
        });
  }

  @Test
  public void testBuildWithEmptyColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    TableDTO.Builder<?> builder =
        TableDTO.builder().withName("t1").withAudit(audit).withColumns(new ColumnDTO[0]);

    Assertions.assertDoesNotThrow(
        () -> {
          builder.build();
        });
  }

  @Test
  public void testBuildWithColumns() {
    AuditDTO audit =
        AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build();
    ColumnDTO column =
        ColumnDTO.builder().withName("c1").withDataType(Types.IntegerType.get()).build();
    TableDTO.Builder<?> builder =
        TableDTO.builder().withName("t1").withAudit(audit).withColumns(new ColumnDTO[] {column});
    assertDoesNotThrow(builder::build);
  }
}
